@@ -25,7 +25,7 @@ mas = (1.0*u.mas).to(u.deg).value
 earth_sun_mass_ratio = (constants.M_earth/constants.M_sun).value
 tbegin = 2014.6670  # time (in years) of Gaia's first observations
 
-use_backup = False  # If set to true use simpler backup Kepler equation solver.
+use_backup = True  # If set to true use simpler backup Kepler equation solver.
 
 # loads data needed to find astrometric error as functon of magnitude
 local_dir = os.path.dirname(__file__)  # <-- absolute dir the script is in
@@ -229,6 +229,13 @@ def conditional_njit(backup=None):
     return decorator
 
 
+def findEtas(ts, period, eccentricity, tPeri=0, N_it=10):
+    if use_backup==True:
+        etas = findEtas_backup(ts, period, eccentricity, tPeri=tPeri)
+    else:
+        etas = findEtas_full(ts, period, eccentricity, tPeri=tPeri,N_it=N_it)
+    return etas
+
 # finds an (approximate) eccentric anomaly (see Penoyre & Sandford 2019, appendix A)
 def findEtas_backup(ts, period, eccentricity, tPeri=0):
     #print('using backup Kepler equation solver')
@@ -238,9 +245,8 @@ def findEtas_backup(ts, period, eccentricity, tPeri=0):
     eta3s = (eccentricity**3)*np.sin(eta0s)*(1-(3/2)*np.sin(eta0s)**2)
     return eta0s+eta1s+eta2s+eta3s
 
-
 @conditional_njit(findEtas_backup)
-def findEtas(ts, period, eccentricity, tPeri=0, N_it=10):
+def findEtas_full(ts, period, eccentricity, tPeri=0, N_it=10):
     """Solve Kepler's equation, E - e sin E = ell, via the contour integration method of Philcox et al. (2021)
     This uses techniques described in Ullisch (2020) to solve the `geometric goat problem'.
     Args:
@@ -254,9 +260,6 @@ def findEtas(ts, period, eccentricity, tPeri=0, N_it=10):
 
     Slightly edited version of code taken from https://github.com/oliverphilcox/Keplers-Goat-Herd
     """
-    if use_backup == True:
-        return findEtas_backup(ts, period, eccentricity, tPeri=tPeri)
-
     ell_array = ((2*np.pi/period)*(ts-tPeri)) % (2.0*np.pi)
 
     # Check inputs
